# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.administration.account.v1 import preferences_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_preferences__pb2
from _qwak_proto.qwak.administration.account.v1 import terms_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_terms__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/administration/account/v1/account.proto\x12\x1eqwak.administration.account.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x30qwak/administration/account/v1/preferences.proto\x1a*qwak/administration/account/v1/terms.proto\"\xf7\x03\n\x07\x41\x63\x63ount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x45\n\x06status\x18\x04 \x01(\x0e\x32\x35.qwak.administration.account.v1.AccountActivityStatus\x12\x44\n\x0bpreferences\x18\x07 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x1e\n\x16\x64\x65\x66\x61ult_environment_id\x18\x08 \x01(\t\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x04type\x18\t \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\n \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\x12I\n\x0e\x61\x63\x63\x65pted_terms\x18\x0b \x01(\x0b\x32\x31.qwak.administration.account.AccountAcceptedTerms\"c\n\x11ListAccountFilter\x12N\n\x0f\x61\x63tivity_status\x18\x01 \x01(\x0e\x32\x35.qwak.administration.account.v1.AccountActivityStatus\"_\n\x12\x41utoBindingAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12=\n\x04rule\x18\x02 \x01(\x0b\x32/.qwak.administration.account.v1.AutoBindingRule\")\n\x0f\x41utoBindingRule\x12\x16\n\x0e\x65mail_hostname\x18\x01 \x01(\t*k\n\x15\x41\x63\x63ountActivityStatus\x12\x1a\n\x16\x41\x43\x43OUNT_STATUS_INVALID\x10\x00\x12\x19\n\x15\x41\x43\x43OUNT_STATUS_ACTIVE\x10\x01\x12\x1b\n\x17\x41\x43\x43OUNT_STATUS_DISABLED\x10\x02*=\n\x0b\x41\x63\x63ountType\x12\x18\n\x14\x41\x43\x43OUNT_TYPE_INVALID\x10\x00\x12\n\n\x06HYBRID\x10\x01\x12\x08\n\x04SAAS\x10\x02*L\n\x0b\x41\x63\x63ountTier\x12\x18\n\x14\x41\x43\x43OUNT_TIER_INVALID\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\r\n\tVALIDATED\x10\x02\x12\n\n\x06PAYING\x10\x03\x42\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')

_ACCOUNTACTIVITYSTATUS = DESCRIPTOR.enum_types_by_name['AccountActivityStatus']
AccountActivityStatus = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTACTIVITYSTATUS)
_ACCOUNTTYPE = DESCRIPTOR.enum_types_by_name['AccountType']
AccountType = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTTYPE)
_ACCOUNTTIER = DESCRIPTOR.enum_types_by_name['AccountTier']
AccountTier = enum_type_wrapper.EnumTypeWrapper(_ACCOUNTTIER)
ACCOUNT_STATUS_INVALID = 0
ACCOUNT_STATUS_ACTIVE = 1
ACCOUNT_STATUS_DISABLED = 2
ACCOUNT_TYPE_INVALID = 0
HYBRID = 1
SAAS = 2
ACCOUNT_TIER_INVALID = 0
FREE = 1
VALIDATED = 2
PAYING = 3


_ACCOUNT = DESCRIPTOR.message_types_by_name['Account']
_LISTACCOUNTFILTER = DESCRIPTOR.message_types_by_name['ListAccountFilter']
_AUTOBINDINGACCOUNT = DESCRIPTOR.message_types_by_name['AutoBindingAccount']
_AUTOBINDINGRULE = DESCRIPTOR.message_types_by_name['AutoBindingRule']
Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'qwak.administration.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.Account)
  })
_sym_db.RegisterMessage(Account)

ListAccountFilter = _reflection.GeneratedProtocolMessageType('ListAccountFilter', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTFILTER,
  '__module__' : 'qwak.administration.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.ListAccountFilter)
  })
_sym_db.RegisterMessage(ListAccountFilter)

AutoBindingAccount = _reflection.GeneratedProtocolMessageType('AutoBindingAccount', (_message.Message,), {
  'DESCRIPTOR' : _AUTOBINDINGACCOUNT,
  '__module__' : 'qwak.administration.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.AutoBindingAccount)
  })
_sym_db.RegisterMessage(AutoBindingAccount)

AutoBindingRule = _reflection.GeneratedProtocolMessageType('AutoBindingRule', (_message.Message,), {
  'DESCRIPTOR' : _AUTOBINDINGRULE,
  '__module__' : 'qwak.administration.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.AutoBindingRule)
  })
_sym_db.RegisterMessage(AutoBindingRule)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _ACCOUNTACTIVITYSTATUS._serialized_start=954
  _ACCOUNTACTIVITYSTATUS._serialized_end=1061
  _ACCOUNTTYPE._serialized_start=1063
  _ACCOUNTTYPE._serialized_end=1124
  _ACCOUNTTIER._serialized_start=1126
  _ACCOUNTTIER._serialized_end=1202
  _ACCOUNT._serialized_start=208
  _ACCOUNT._serialized_end=711
  _LISTACCOUNTFILTER._serialized_start=713
  _LISTACCOUNTFILTER._serialized_end=812
  _AUTOBINDINGACCOUNT._serialized_start=814
  _AUTOBINDINGACCOUNT._serialized_end=909
  _AUTOBINDINGRULE._serialized_start=911
  _AUTOBINDINGRULE._serialized_end=952
# @@protoc_insertion_point(module_scope)
